@@ -3,24 +3,26 @@
 #' @template rox_spcv_block
 #'
 #' @references
-#' `r tools::toRd(bibentries["valavi2018"])`
+#' `r format_bib("valavi2018")`
 #'
 #' @export
 #' @examples
-#' library(mlr3)
-#' task = tsk("ecuador")
+#' if (mlr3misc::require_namespaces(c("sf", "blockCV"), quietly = TRUE)) {
+#'   library(mlr3)
+#'   task = tsk("ecuador")
 #'
-#' # Instantiate Resampling
-#' rcv = rsmp("spcv_block", range = 1000)
-#' rcv$instantiate(task)
+#'   # Instantiate Resampling
+#'   rcv = rsmp("spcv_block", range = 1000)
+#'   rcv$instantiate(task)
 #'
-#' # Individual sets:
-#' rcv$train_set(1)
-#' rcv$test_set(1)
-#' intersect(rcv$train_set(1), rcv$test_set(1))
+#'   # Individual sets:
+#'   rcv$train_set(1)
+#'   rcv$test_set(1)
+#'   intersect(rcv$train_set(1), rcv$test_set(1))
 #'
-#' # Internal storage:
-#' rcv$instance
+#'   # Internal storage:
+#'   rcv$instance
+#' }
 ResamplingSpCVBlock = R6Class("ResamplingSpCVBlock",
   inherit = mlr3::Resampling,
 
@@ -44,7 +46,7 @@ ResamplingSpCVBlock = R6Class("ResamplingSpCVBlock",
         id = id,
         param_set = ps
       )
-      require_namespaces(c("blockCV", "sf"))
+      mlr3misc::require_namespaces(c("blockCV", "sf"))
     },
 
     #' @description
