@@ -27,16 +27,18 @@
 #' @export
 #' @examples
 #' \donttest{
-#' library(mlr3)
-#' library(mlr3spatiotempcv)
-#' task_st = tsk("cookfarm")
-#' resampling = rsmp("sptcv_cstf", folds = 5, time_var = "Date")
-#' resampling$instantiate(task_st)
+#' if (mlr3misc::require_namespaces(c("sf", "skmeans", "plotly"), quietly = TRUE)) {
+#'   library(mlr3)
+#'   library(mlr3spatiotempcv)
+#'   task_st = tsk("cookfarm")
+#'   resampling = rsmp("sptcv_cstf", folds = 5, time_var = "Date")
+#'   resampling$instantiate(task_st)
 #'
-#' # plot
-#' autoplot(resampling, task_st)
-#' autoplot(resampling, task_st, 1)
-#' autoplot(resampling, task_st, c(1, 2))
+#'   # plot
+#'   autoplot(resampling, task_st)
+#'   autoplot(resampling, task_st, 1)
+#'   autoplot(resampling, task_st, c(1, 2))
+#' }
 #' }
 autoplot.ResamplingSptCVCstf = function( # nolint
   object,
@@ -58,7 +60,7 @@ autoplot.ResamplingSptCVCstf = function( # nolint
   resampling = object
   coords = task$coordinates()
   coords$row_id = task$row_ids
-  require_namespaces(c("sf", "patchwork", "ggtext"))
+  mlr3misc::require_namespaces(c("sf", "patchwork", "ggtext"))
 
   resampling = assert_autoplot(resampling, fold_id, task)
 
